==> custom_pages-v1.12.8.zip: custom_pages/messages/ar/base.php <==
<?php

return [
    '<strong>Custom</strong> Pages' => 'صفحات <strong>مخصصة</strong>',
    '<strong>Edit</strong> snippet' => '<strong>تحرير</strong> المقتطف',
    'Add' => 'إضافة',
    'Add a file icon before the title' => 'أضف أيقونة الملف قبل العنوان',
    'Adds plain HTML content to your site.' => 'يضيف محتوى HTML عادي إلى موقعك.',
    'Advanced' => 'متقدم',
    'Allows the user to manage custom pages.' => 'يسمح للمستخدم بإدارة الصفحات المخصصة.',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => 'يسمح بإضافة صفحات (ماركداون أو iframe أو روابط) إلى التنقل في الباحة',
    'Allows you to add content in MarkDown syntax.' => 'يسمح لك بإضافة محتوى في صيغة MarkDown.',
    'Alternate text' => 'النص البديل',
    'Always make a backup of your view files outside of your production environment!' => 'قم دائمًا بعمل نسخة احتياطية من ملفات العرض الخاصة بك خارج بيئة الإنتاج الخاصة بك!',
    'An empty allowed template selection will allow all container templates for this container.' => 'سيسمح اختيار القالب المسموح به الفارغ بجميع قوالب الحاوية لهذه الحاوية.',
    'Back' => 'عودة',
    'Back to dashboard' => 'عودة للوحة القيادة',
    'Back to overview' => 'الرجوع إلى النظرة العامة',
    'Back to space' => 'عودة إلى الباحة',
    'Can manage custom pages' => 'يستطيع إدارة الصفحات المخصصة',
    'Cannot delete!' => 'لا يمكن الحذف!',
    'Category' => 'الفئة',
    'Configuration' => 'إعدادات',
    'Content' => 'المحتوى',
    'Css Class' => 'فئة CSS',
    'Custom' => 'تخصيص',
    'Custom Pages' => 'الصفحات المخصصة',
    'Custom pages' => 'الصفحات المخصصة',
    'Dashboard' => 'لوحة القيادة',
    'Default' => 'الافتراضي',
    'Default Content' => 'المحتوى الافتراضي',
    'Delete' => 'حذف',
    'Deleted.' => 'تم حذفه.',
    'Edit' => 'تحرير',
    'Edit Page' => 'تحرير الصفحة',
    'Empty' => 'فارغ',
    'File' => 'ملف',
    'Footer menu' => 'قائمة التذييل',
    'General' => 'العام',
    'Global Page' => 'صفحة عامة',
    'ID' => '@ID@',
    'Insert' => 'إدراج',
    'Menu settings' => 'إعدادات القائمة',
    'Overview' => 'نظرة شاملة',
    'Public' => 'عام',
    'Reset' => 'إعادة ضبط',
    'Settings' => 'الإعدادات',
    'Snippet' => 'المقتطف',
    'Sort Order' => 'طريقة الفرز',
    'Source' => 'المصدر',
    'Space' => 'الباحة',
    'Spaces' => 'الباحات',
    'Stream' => 'ستريم',
    'Submit' => 'أرسل',
    'Title' => 'العنوان',
    'Topics' => 'المواضيع',
    'Type' => 'نوع',
    'Visibility' => 'الرؤية',
    '<strong>Add</strong> {templateName} item' => '',
    'Additional IFrame Attributes' => '',
    'Administrative Users' => '',
    'Always' => '',
    'Authors' => '',
    'Container' => '',
    'Content filters' => '',
    'Create' => '',
    'Empty content elements cannot be deleted!' => '',
    'Enter post content ID' => '',
    'Global Widget' => '',
    'Go Back' => '',
    'Html' => '',
    'Icon' => '',
    'Iframe' => '',
    'Import' => '',
    'Invalid request data!' => '',
    'Invalid template selection!' => '',
    'Invalid type selection' => '',
    'Invalid view file selection!' => '',
    'Layout' => '',
    'Leave empty to list all records related to the current user.' => '',
    'Limit' => '',
    'Link' => '',
    'Logged-In Users' => '',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => '',
    'MarkDown' => '',
    'Navigation' => '',
    'Non-Logged-In Users' => '',
    'On this page you can configure general settings of your custom pages.' => '',
    'PHP' => '',
    'Page' => '',
    'Page Content' => '',
    'Pages' => '',
    'Panel' => '',
    'People Buttons' => '',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => '',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => '',
    'Reset the content to default value' => '',
    'Resources' => '',
    'Restrict to following comma separated content IDs' => '',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => '',
    'Show additional file information (size)' => '',
    'Snippets' => '',
    'Space Members only' => '',
    'Space Navigation' => '',
    'Space Page' => '',
    'Space Widget' => '',
    'Start Page' => '',
    'Stream options' => '',
    'Style' => '',
    'Style Class' => '',
    'Target Url' => '',
    'Template' => '',
    'Template Layout' => '',
    'Templates' => '',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => '',
    'This container does not allow any further items!' => '',
    'Top Navigation' => '',
    'Upload image' => '',
    'Usage' => '',
    'User Account Menu (Settings)' => '',
    'Will embed the result of a given url as an iframe element.' => '',
    'Will redirect requests to a given (relative or absolute) url.' => '',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => '',
    'Without adding to navigation (Direct link)' => '',
    'Wrap this HTML page with white panel' => '',
    'You are not allowed to delete default content!' => '',
];

==> custom_pages-v1.12.14.zip: custom_pages/messages/ar/base.php <==
<?php

return [
    '<strong>Custom</strong> Pages' => 'صفحات <strong>مخصصة</strong>',
    '<strong>Edit</strong> snippet' => '<strong>تحرير</strong> المقتطف',
    'Add' => 'إضافة',
    'Add a file icon before the title' => 'أضف أيقونة الملف قبل العنوان',
    'Adds plain HTML content to your site.' => 'يضيف محتوى HTML عادي إلى موقعك.',
    'Advanced' => 'متقدم',
    'Allows the user to manage custom pages.' => 'يسمح للمستخدم بإدارة الصفحات المخصصة.',
    'Allows to add pages (markdown, iframe or links) to the space navigation' => 'يسمح بإضافة صفحات (ماركداون أو iframe أو روابط) إلى التنقل في الباحة',
    'Allows you to add content in MarkDown syntax.' => 'يسمح لك بإضافة محتوى في صيغة MarkDown.',
    'Alternate text' => 'النص البديل',
    'Always make a backup of your view files outside of your production environment!' => 'قم دائمًا بعمل نسخة احتياطية من ملفات العرض الخاصة بك خارج بيئة الإنتاج الخاصة بك!',
    'An empty allowed template selection will allow all container templates for this container.' => 'سيسمح اختيار القالب المسموح به الفارغ بجميع قوالب الحاوية لهذه الحاوية.',
    'Back' => 'عودة',
    'Back to dashboard' => 'عودة للوحة القيادة',
    'Back to overview' => 'الرجوع إلى النظرة العامة',
    'Back to space' => 'عودة إلى الباحة',
    'Can manage custom pages' => 'يستطيع إدارة الصفحات المخصصة',
    'Cannot delete!' => 'لا يمكن الحذف!',
    'Category' => 'الفئة',
    'Configuration' => 'إعدادات',
    'Content' => 'المحتوى',
    'Css Class' => 'فئة CSS',
    'Custom' => 'تخصيص',
    'Custom Pages' => 'الصفحات المخصصة',
    'Custom pages' => 'الصفحات المخصصة',
    'Dashboard' => 'لوحة القيادة',
    'Default' => 'الافتراضي',
    'Default Content' => 'المحتوى الافتراضي',
    'Delete' => 'حذف',
    'Deleted.' => 'تم حذفه.',
    'Edit' => 'تحرير',
    'Edit Page' => 'تحرير الصفحة',
    'Empty' => 'فارغ',
    'File' => 'ملف',
    'Footer menu' => 'قائمة التذييل',
    'General' => 'العام',
    'Global Page' => 'صفحة عامة',
    'ID' => '@ID@',
    'Insert' => 'إدراج',
    'Menu settings' => 'إعدادات القائمة',
    'Overview' => 'نظرة شاملة',
    'Public' => 'عام',
    'Reset' => 'إعادة ضبط',
    'Settings' => 'الإعدادات',
    'Snippet' => 'المقتطف',
    'Sort Order' => 'طريقة الفرز',
    'Source' => 'المصدر',
    'Space' => 'الباحة',
    'Spaces' => 'الباحات',
    'Stream' => 'ستريم',
    'Submit' => 'أرسل',
    'Title' => 'العنوان',
    'Topics' => 'المواضيع',
    'Type' => 'نوع',
    'Visibility' => 'الرؤية',
    '<strong>Add</strong> {templateName} item' => '',
    'Activities' => '',
    'Activity' => '',
    'Activity content ID' => '',
    'Additional IFrame Attributes' => '',
    'Administrative Users' => '',
    'Always' => '',
    'Authors' => '',
    'By creation date' => '',
    'By last update' => '',
    'Container' => '',
    'Content filters' => '',
    'Create' => '',
    'Determine which Spaces should be taken into account.' => '',
    'Empty content elements cannot be deleted!' => '',
    'Enter post content ID' => '',
    'Global Widget' => '',
    'Go Back' => '',
    'Html' => '',
    'Icon' => '',
    'Iframe' => '',
    'Import' => '',
    'Include all Spaces except selected' => '',
    'Include selected Spaces only' => '',
    'Invalid request data!' => '',
    'Invalid template selection!' => '',
    'Invalid type selection' => '',
    'Invalid view file selection!' => '',
    'Layout' => '',
    'Leave empty to list all records related to the current user.' => '',
    'Limit' => '',
    'Link' => '',
    'Logged-In Users' => '',
    'Manage layouts, snippet layouts, and containers. Layouts define page structures, snippet layouts are used in sidebars or sections, and containers are reusable content blocks.' => '',
    'MarkDown' => '',
    'Navigation' => '',
    'Non-Logged-In Users' => '',
    'On this page you can configure general settings of your custom pages.' => '',
    'PHP' => '',
    'Page' => '',
    'Page Content' => '',
    'Pages' => '',
    'Panel' => '',
    'People Buttons' => '',
    'Please choose one of the following content types. The content type defines how your content is embedded to your site.' => '',
    'Please keep in mind that php based pages are vulnerable to security issues, especially when handling user input. For more information, please have a look at <a href="{url}">Yii\'s Security best practices</a>.' => '',
    'Reset the content to default value' => '',
    'Resources' => '',
    'Restrict to following comma separated content IDs' => '',
    'Select this setting for visible text nodes only. Uncheck this setting in case this element is used for example as HTML attribute value.' => '',
    'Show additional file information (size)' => '',
    'Snippets' => '',
    'Sorting' => '',
    'Space Members only' => '',
    'Space Navigation' => '',
    'Space Page' => '',
    'Space Widget' => '',
    'Space selection' => '',
    'Start Page' => '',
    'Stream options' => '',
    'Style' => '',
    'Style Class' => '',
    'Target Url' => '',
    'Template' => '',
    'Template Layout' => '',
    'Templates' => '',
    'Templates allow you to define combinable page fragments with inline edit functionality.' => '',
    'This container does not allow any further items!' => '',
    'Top Navigation' => '',
    'Upload image' => '',
    'Usage' => '',
    'User Account Menu (Settings)' => '',
    'Will embed the result of a given url as an iframe element.' => '',
    'Will redirect requests to a given (relative or absolute) url.' => '',
    'With PHP based pages you can create custom pages by means of view files in your file system. Please check the module configuration for more Information.' => '',
    'Without adding to navigation (Direct link)' => '',
    'Wrap this HTML page with white panel' => '',
    'You are not allowed to delete default content!' => '',
];
